==> dojo-1.9.4.tgz: package/cldr/nls/fi/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"field-dayperiod": "vuorokaudenaika",
	"field-minute": "minuutti",
	"dateFormatItem-MMMEd": "ccc d. MMM",
	"dateTimeFormat-full": "{1} {0}",
	"field-day-relative+-1": "eilen",
	"dateFormatItem-hms": "h.mm.ss a",
	"field-day-relative+-2": "toissapäivänä",
	"field-weekday": "viikonpäivä",
	"dateFormatItem-MMM": "LLL",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Gy": "y G",
	"dateTimeFormat-medium": "{1} {0}",
	"field-era": "aikakausi",
	"field-hour": "tunti",
	"dateFormatItem-y": "y G",
	"dateFormatItem-yyyy": "y G",
	"dateFormatItem-Ed": "E d.",
	"field-day-relative+0": "tänään",
	"field-day-relative+1": "huomenna",
	"field-day-relative+2": "ylihuomenna",
	"dateFormatItem-yyyyMM": "M.y G",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"dateFormatItem-yyyyMMMMccccd": "cccc d. MMMM y G",
	"dateFormat-long": "d. MMMM y G",
	"field-zone": "aikavyöhyke",
	"dateFormatItem-Hm": "H.mm",
	"field-week-relative+-1": "viime viikolla",
	"dateFormat-medium": "d.M.y G",
	"dateFormatItem-Hms": "H.mm.ss",
	"field-year-relative+0": "tänä vuonna",
	"field-year-relative+1": "ensi vuonna",
	"field-year-relative+-1": "viime vuonna",
	"dateFormatItem-ms": "mm.ss",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"field-year": "vuosi",
	"dateTimeFormat-long": "{1} {0}",
	"field-week": "viikko",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"dateFormatItem-MMMd": "d. MMM",
	"field-week-relative+0": "tällä viikolla",
	"field-week-relative+1": "ensi viikolla",
	"field-month-relative+0": "tässä kuussa",
	"dateFormatItem-H": "H",
	"field-month": "kuukausi",
	"field-month-relative+1": "ensi kuussa",
	"dateFormatItem-M": "L",
	"field-second": "sekunti",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-day": "päivä",
	"dateFormatItem-MEd": "E d.M.",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateFormatItem-hm": "h.mm a",
	"dateFormat-short": "d.M.y GGGGG",
	"dateFormatItem-yyyyM": "L.y G",
	"dateFormat-full": "cccc d. MMMM y G",
	"dateFormatItem-Md": "d.M.",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"dateFormatItem-d": "d",
	"field-month-relative+-1": "viime kuussa",
	"dateFormatItem-h": "h a"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/fi/generic.js <==
define(
//begin v1.x content
{
	"field-second-relative+0": "nyt",
	"field-weekday": "viikonpäivä",
	"field-wed-relative+0": "tänä keskiviikkona",
	"dateFormatItem-GyMMMEd": "E d. MMM y G",
	"dateFormatItem-MMMEd": "ccc d. MMM",
	"field-wed-relative+1": "ensi keskiviikkona",
	"field-tue-relative+-1": "viime tiistaina",
	"dateFormat-long": "d. MMMM y G",
	"field-fri-relative+-1": "viime perjantaina",
	"field-wed-relative+-1": "viime keskiviikkona",
	"dateFormatItem-yyyyQQQ": "QQQ y G",
	"dateTimeFormat-medium": "{1} 'klo' {0}",
	"dateFormat-full": "cccc d. MMMM y G",
	"dateFormatItem-yyyyMEd": "E d.M.y G",
	"field-thu-relative+-1": "viime torstaina",
	"dateFormatItem-Md": "d.M.",
	"field-era": "aikakausi",
	"field-year": "vuosi",
	"dateFormatItem-yyyyMMMM": "LLLL y G",
	"field-hour": "tunti",
	"field-sat-relative+0": "tänä lauantaina",
	"field-sat-relative+1": "ensi lauantaina",
	"field-day-relative+0": "tänään",
	"field-day-relative+1": "huomenna",
	"field-thu-relative+0": "tänä torstaina",
	"dateFormatItem-GyMMMd": "d. MMM y G",
	"field-day-relative+2": "ylihuomenna",
	"field-thu-relative+1": "ensi torstaina",
	"dateFormatItem-H": "H",
	"dateFormatItem-Gy": "y G",
	"dateFormatItem-yyyyMMMEd": "E d. MMM y G",
	"dateFormatItem-M": "L",
	"dateFormatItem-yyyyMMM": "LLL y G",
	"dateFormatItem-yyyyMMMd": "d. MMM y G",
	"field-sun-relative+0": "tänä sunnuntaina",
	"dateFormatItem-Hm": "H.mm",
	"field-sun-relative+1": "ensi sunnuntaina",
	"field-minute": "minuutti",
	"field-dayperiod": "vuorokaudenaika",
	"dateFormatItem-d": "d",
	"dateFormatItem-ms": "mm.ss",
	"field-day-relative+-1": "eilen",
	"dateFormatItem-h": "h a",
	"dateTimeFormat-long": "{1} 'klo' {0}",
	"field-day-relative+-2": "toissa päivänä",
	"dateFormatItem-MMMd": "d. MMM",
	"dateFormatItem-MEd": "E d.M.",
	"dateTimeFormat-full": "{1} 'klo' {0}",
	"dateFormatItem-yyyyMMMMccccd": "cccc d. MMMM y G",
	"field-fri-relative+0": "tänä perjantaina",
	"field-fri-relative+1": "ensi perjantaina",
	"field-day": "päivä",
	"field-zone": "aikavyöhyke",
	"dateFormatItem-yyyyMM": "M.y G",
	"dateFormatItem-y": "y G",
	"field-year-relative+-1": "viime vuonna",
	"field-month-relative+-1": "viime kuussa",
	"dateFormatItem-hm": "h.mm a",
	"dateFormatItem-yyyyMd": "d.M.y G",
	"field-month": "kuukausi",
	"dateFormatItem-MMM": "LLL",
	"field-tue-relative+0": "tänä tiistaina",
	"field-tue-relative+1": "ensi tiistaina",
	"field-mon-relative+0": "tänä maanantaina",
	"field-mon-relative+1": "ensi maanantaina",
	"dateFormat-short": "d.M.y GGGGG",
	"field-second": "sekunti",
	"field-sat-relative+-1": "viime lauantaina",
	"field-sun-relative+-1": "viime sunnuntaina",
	"field-month-relative+0": "tässä kuussa",
	"field-month-relative+1": "ensi kuussa",
	"dateFormatItem-Ed": "E d.",
	"field-week": "viikko",
	"dateFormat-medium": "d.M.y G",
	"field-year-relative+0": "tänä vuonna",
	"field-week-relative+-1": "viime viikolla",
	"dateFormatItem-yyyyM": "L.y G",
	"field-year-relative+1": "ensi vuonna",
	"dateFormatItem-yyyyQQQQ": "QQQQ y G",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-Hms": "H.mm.ss",
	"dateFormatItem-hms": "h.mm.ss a",
	"dateFormatItem-GyMMM": "LLL y G",
	"field-mon-relative+-1": "viime maanantaina",
	"dateFormatItem-yyyy": "y G",
	"field-week-relative+0": "tällä viikolla",
	"field-week-relative+1": "ensi viikolla"
}
//end v1.x content
);
